@@ -80,14 +80,17 @@ class Core(component.Component):
         log.info("Starting libtorrent %s session..", lt.version)
 
         # Create the client fingerprint
-        version = [int(value.split("-")[0]) for value in deluge.common.get_version().split(".")]
+        version = deluge.common.VersionSplit(deluge.common.get_version()).version
         while len(version) < 4:
             version.append(0)
 
-        # Note: All libtorrent python bindings to set plugins/extensions need to be disabled
-        # due to  GIL issue. https://code.google.com/p/libtorrent/issues/detail?id=369
-        # Setting session flags to 1 enables all libtorrent default plugins
-        self.session = lt.session(lt.fingerprint("DE", *version), flags=1)
+        # In libtorrent versions below 0.16.7.0 disable extension bindings due to GIL issue.
+        # https://code.google.com/p/libtorrent/issues/detail?id=369
+        if deluge.common.VersionSplit(lt.version) >= deluge.common.VersionSplit("0.16.7.0"):
+            self.session = lt.session(lt.fingerprint("DE", *version), flags=0)
+        else:
+            # Setting session flags to 1 enables all libtorrent default plugins
+            self.session = lt.session(lt.fingerprint("DE", *version), flags=1)
 
         # Load the session state if available
         self.__load_session_state()
@@ -108,11 +111,12 @@ class Core(component.Component):
         self.session.set_settings(self.settings)
 
         # Load metadata extension
-        # Note: All libtorrent python bindings to set plugins/extensions need to be disabled
-        # due to  GIL issue. https://code.google.com/p/libtorrent/issues/detail?id=369
-        # self.session.add_extension(lt.create_metadata_plugin)
-        # self.session.add_extension(lt.create_ut_metadata_plugin)
-        # self.session.add_extension(lt.create_smart_ban_plugin)
+        # In libtorrent versions below 0.16.7.0 disable extension bindings due to GIL issue.
+        # https://code.google.com/p/libtorrent/issues/detail?id=369
+        if deluge.common.VersionSplit(lt.version) >= deluge.common.VersionSplit("0.16.7.0"):
+            self.session.add_extension("metadata_transfer")
+            self.session.add_extension("ut_metadata")
+            self.session.add_extension("smart_ban")
 
         # Create the components
         self.eventmanager = EventManager()
