@@ -60,6 +60,17 @@ if windows_check():
         'C:\\Program Files\\7-Zip\\7z.exe',
         'C:\\Program Files (x86)\\7-Zip\\7z.exe',
     ]
+
+    import _winreg
+    try:
+        hkey = _winreg.OpenKey(_winreg.HKEY_CURRENT_USER, "Software\\7-Zip")
+    except WindowsError:
+        pass
+    else:
+        win_7z_path = os.path.join(_winreg.QueryValueEx(hkey, "Path")[0], "7z.exe")
+        _winreg.CloseKey(hkey)
+        win_7z_exes.insert(1, win_7z_path)
+
     switch_7z = "x -y"
     ## Future suport:
     ## 7-zip cannot extract tar.* with single command.
@@ -99,7 +110,7 @@ else:
         if not which(cmd):
             for k,v in EXTRACT_COMMANDS.items():
                 if cmd in v[0]:
-                    log.error("EXTRACTOR: %s not found, disabling support for %s", cmd, k)
+                    log.warning("EXTRACTOR: %s not found, disabling support for %s", cmd, k)
                     del EXTRACT_COMMANDS[k]
 
 if not EXTRACT_COMMANDS:
@@ -111,7 +122,6 @@ class Core(CorePluginBase):
         if not self.config["extract_path"]:
             self.config["extract_path"] = deluge.configmanager.ConfigManager("core.conf")["download_location"]
         component.get("EventManager").register_event_handler("TorrentFinishedEvent", self._on_torrent_finished)
-
     def disable(self):
         component.get("EventManager").deregister_event_handler("TorrentFinishedEvent", self._on_torrent_finished)
 
@@ -123,21 +133,18 @@ class Core(CorePluginBase):
         This is called when a torrent finishes and checks if any files to extract.
         """
         tid = component.get("TorrentManager").torrents[torrent_id]
-        tid_status = tid.get_status(["save_path", "move_completed", "name"])
-
-        if tid_status["move_completed"]:
-            log.error("EXTRACTOR: Cannot extract torrents with 'Move Completed' enabled")
-            return
+        tid_status = tid.get_status(["save_path", "name"])
 
         files = tid.get_files()
         for f in files:
-            cmd = ''
-            file_ext = os.path.splitext(os.path.splitext(f["path"])[0])[1] + os.path.splitext(f["path"])[1]
-            if file_ext in EXTRACT_COMMANDS:
-                cmd = EXTRACT_COMMANDS[file_ext]
-            else:
-                log.error("EXTRACTOR: Can't extract unknown file type: %s", file_ext)
+            file_root, file_ext = os.path.splitext(f["path"])
+            file_ext_sec = os.path.splitext(file_root)[1]
+            if file_ext_sec and file_ext_sec + file_ext in EXTRACT_COMMANDS:
+                file_ext = file_ext_sec + file_ext
+            elif file_ext not in EXTRACT_COMMANDS or file_ext_sec == '.tar':
+                log.warning("EXTRACTOR: Can't extract file with unknown file type: %s" % f["path"])
                 continue
+            cmd = EXTRACT_COMMANDS[file_ext]
 
             # Now that we have the cmd, lets run it to extract the files
             fpath = os.path.join(tid_status["save_path"], os.path.normpath(f["path"]))
@@ -165,11 +172,10 @@ class Core(CorePluginBase):
                 log.error("EXTRACTOR: Extract failed: %s (%s)", fpath, torrent_id)
 
             # Run the command and add some callbacks
-            if cmd:
-                log.debug("EXTRACTOR: Extracting %s with %s %s to %s", fpath, cmd[0], cmd[1], dest)
-                d = getProcessValue(cmd[0], cmd[1].split() + [str(fpath)], {}, str(dest))
-                d.addCallback(on_extract_success, torrent_id, fpath)
-                d.addErrback(on_extract_failed, torrent_id, fpath)
+            log.debug("EXTRACTOR: Extracting %s with %s %s to %s", fpath, cmd[0], cmd[1], dest)
+            d = getProcessValue(cmd[0], cmd[1].split() + [str(fpath)], {}, str(dest))
+            d.addCallback(on_extract_success, torrent_id, fpath)
+            d.addErrback(on_extract_failed, torrent_id, fpath)
 
     @export
     def set_config(self, config):
