@@ -190,6 +190,7 @@ class MenuBar(component.Component):
                 self.torrentmenu_glade.get_widget(widget).set_no_show_all(True)
         else:
             for widget in non_remote_items:
+                self.torrentmenu_glade.get_widget(widget).show()
                 self.torrentmenu_glade.get_widget(widget).set_no_show_all(False)
 
         self.window.main_glade.get_widget("separatormenuitem").set_visible(not self.config["classic_mode"])
@@ -306,7 +307,8 @@ class MenuBar(component.Component):
     def on_menuitem_open_folder_activate(self, data=None):
         log.debug("on_menuitem_open_folder")
         def _on_torrent_status(status):
-            deluge.common.open_file(status["save_path"])
+            timestamp = gtk.get_current_event_time()
+            deluge.common.open_file(status["save_path"], timestamp=timestamp)
         for torrent_id in component.get("TorrentView").get_selected_torrents():
             component.get("SessionProxy").get_torrent_status(torrent_id, ["save_path"]).addCallback(_on_torrent_status)
 
