@@ -135,10 +135,13 @@ def cell_data_trackericon(column, cell, model, row, data):
             pixbuf = create_blank_pixbuf()
 
         #Supress Warning: g_object_set_qdata: assertion `G_IS_OBJECT (object)' failed
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
+        original_filters = warnings.filters[:]
+        warnings.simplefilter("ignore")
+        try:
             if cell.get_property("pixbuf") != pixbuf:
                 cell.set_property("pixbuf", pixbuf)
+        finally:
+            warnings.filters = original_filters
 
     host = model[row][data]
     if host:
@@ -155,7 +158,7 @@ def cell_data_progress(column, cell, model, row, data):
 
     textstr = _t(state_str)
     if state_str != "Seeding" and value < 100:
-        textstr = textstr + " %.2f%%" % value
+        textstr = "%s %.2f%%" % (textstr, value)
     if cell.get_property("text") != textstr:
         cell.set_property("text", textstr)
 
@@ -283,6 +286,7 @@ class TorrentView(listview.ListView, component.Component):
                                  function=cell_data_trackericon, default=False)
 
         self.add_text_column(_("Save Path"), status_field=["save_path"], default=False)
+        self.restore_columns_order_from_state()
 
         # Set filter to None for now
         self.filter = None
@@ -303,6 +307,7 @@ class TorrentView(listview.ListView, component.Component):
         self.treeview.connect("drag-drop", self.on_drag_drop)
         self.treeview.connect("drag_data_received", self.on_drag_data_received)
         self.treeview.connect("key-press-event", self.on_key_press_event)
+        self.treeview.connect("columns-changed", self.on_columns_changed_event)
 
         client.register_event_handler("TorrentStateChangedEvent", self.on_torrentstatechanged_event)
         client.register_event_handler("TorrentAddedEvent", self.on_torrentadded_event)
@@ -318,18 +323,12 @@ class TorrentView(listview.ListView, component.Component):
         component.get("SessionProxy").get_torrents_status({}, []).addCallback(self._on_session_state)
 
     def _on_session_state(self, state):
-        self.treeview.freeze_child_notify()
-        model = self.treeview.get_model()
-        for torrent_id in state:
-            self.add_row(torrent_id, update=False)
-            self.mark_dirty(torrent_id)
-        self.treeview.set_model(model)
-        self.treeview.thaw_child_notify()
+        self.add_rows(state)
         self.got_state = True
         # Update the view right away with our status
         self.status = state
         self.set_columns_to_update()
-        self.update_view()
+        self.update_view(load_new_list=True)
 
     def stop(self):
         """Stops the torrentview"""
@@ -404,43 +403,66 @@ class TorrentView(listview.ListView, component.Component):
             # Send a status request
             gobject.idle_add(self.send_status_request)
 
-    def update_view(self, columns=None):
-        """Update the view.  If columns is not None, it will attempt to only
-        update those columns selected.
-        """
+    def update_view(self, load_new_list=False):
+        """Update the torrent view model with data we've received."""
         filter_column = self.columns["filter"].column_indices[0]
-        # Update the torrent view model with data we've received
         status = self.status
-        status_keys = status.keys()
+
+        if not load_new_list:
+            # Freeze notications while updating
+            self.treeview.freeze_child_notify()
+
+        # Get the columns to update from one of the torrents
+        if status:
+            torrent_id = status.keys()[0]
+            fields_to_update = []
+            for column in self.columns_to_update:
+                column_index = self.get_column_index(column)
+                for i, status_field in enumerate(self.columns[column].status_field):
+                    # Only use columns that the torrent has in the state
+                    if status_field in status[torrent_id]:
+                        fields_to_update.append((column_index[i], status_field))
 
         for row in self.liststore:
             torrent_id = row[self.columns["torrent_id"].column_indices[0]]
+            # We expect the torrent_id to be in status and prev_status,
+            # as it will be as long as the list isn't changed by the user
 
-            if not torrent_id in status_keys:
+            torrent_id_in_status = False
+            try:
+                torrent_status = status[torrent_id]
+                torrent_id_in_status = True
+                if torrent_status == self.prev_status[torrent_id]:
+                    # The status dict is the same, so do nothing to update for this torrent
+                    continue
+            except KeyError, e:
+                pass
+
+            if not torrent_id_in_status:
                 if row[filter_column] is True:
                     row[filter_column] = False
             else:
                 if row[filter_column] is False:
                     row[filter_column] = True
-                if torrent_id in self.prev_status and status[torrent_id] == self.prev_status[torrent_id]:
-                    # The status dict is the same, so do not update
-                    continue
 
-                # Set values for each column in the row
-                for column in self.columns_to_update:
-                    column_index = self.get_column_index(column)
-                    for i, status_field in enumerate(self.columns[column].status_field):
-                        if status_field in status[torrent_id]:
-                            try:
-                                # Only update if different
-                                row_value = status[torrent_id][status_field]
-                                if row[column_index[i]] != row_value:
-                                    row[column_index[i]] = row_value
-                            except Exception, e:
-                                log.debug("%s", e)
+                # Find the fields to update
+                to_update = []
+                for i, status_field in fields_to_update:
+                    row_value = status[torrent_id][status_field]
+                    if row[i] != row_value:
+                        to_update.append(i)
+                        to_update.append(row_value)
+                # Update fields in the liststore
+                if to_update:
+                    self.liststore.set(row.iter, *to_update)
+
+        if load_new_list:
+            # Create the model filter. This sets the model for the treeview and enables sorting.
+            self.create_model_filter()
+        else:
+            self.treeview.thaw_child_notify()
 
         component.get("MenuBar").update_menu()
-
         self.prev_status = status
 
     def _on_get_torrents_status(self, status):
@@ -470,6 +492,16 @@ class TorrentView(listview.ListView, component.Component):
         if update:
             self.update()
 
+    def add_rows(self, state):
+        """Adds all the torrents from state to self.liststore"""
+        torrent_id_column = self.columns["torrent_id"].column_indices[0]
+        dirty_column = self.columns["dirty"].column_indices[0]
+        filter_column = self.columns["filter"].column_indices[0]
+        for i, torrent_id in enumerate(state):
+            # Insert a new row to the liststore
+            row = self.liststore.append()
+            self.liststore.set(row, torrent_id_column, torrent_id, dirty_column, True, filter_column, True)
+
     def remove_row(self, torrent_id):
         """Removes a row with torrent_id"""
         for row in self.liststore:
@@ -571,7 +603,13 @@ class TorrentView(listview.ListView, component.Component):
     def on_drag_data_received(self, widget, drag_context, x, y, selection_data, info, timestamp):
         widget.stop_emission("drag_data_received")
 
+    def on_columns_changed_event(self, treeview):
+        log.debug("Treeview Columns Changed")
+        self.save_state()
+
     def on_torrentadded_event(self, torrent_id):
+        if self.got_state is False:
+            return
         self.add_row(torrent_id)
         self.mark_dirty(torrent_id)
 
