@@ -244,7 +244,7 @@ class TrackerIcons(Component):
         """
         Recovers from download error
 
-        :param f: the failure that occured
+        :param f: the failure that occurred
         :type f: Failure
         :param host: the name of the host whose page failed to download
         :type host: string
@@ -311,7 +311,7 @@ class TrackerIcons(Component):
         """
         Recovers from a parse error
 
-        :param f: the failure that occured
+        :param f: the failure that occurred
         :type f: Failure
         :returns: a Deferred if recovery was possible
                   else the original failure
@@ -383,7 +383,7 @@ class TrackerIcons(Component):
         """
         Recovers from a download error
 
-        :param f: the failure that occured
+        :param f: the failure that occurred
         :type f: Failure
         :param host: the host the icon failed to download for
         :type host: string
